==> openGion_dev_5.6.8.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE32S.sql <==
/****************************************************************************/
/* GE32 ( 送信履歴ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2013/09/03 10:23:45                                            */
/****************************************************************************/
CREATE TABLE GE32 (
   YKNO         int                             DEFAULT 0   NOT NULL            /*  10 要求NO   */
 , PARA_KEY     varchar           (    9 )                                      /*  20 ﾊﾟﾗﾒｰﾀｷｰ */
 , PTN_ID       varchar           (   20 )                                      /*  30 定型文ID */
 , SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  40 ｼｽﾃﾑID   */
 , FROM_ADDR    varchar           (  100 )                  NOT NULL            /*  50 送信元   */
 , TITLE        varchar           (  300 )                                      /*  60 ﾀｲﾄﾙ     */
 , CONTENTS     varchar           ( 4000 )                                      /*  70 内容     */
 , ATTACH1      varchar           (  256 )                                      /*  80 添付1    */
 , ATTACH2      varchar           (  256 )                                      /*  90 添付2    */
 , ATTACH3      varchar           (  256 )                                      /* 100 添付3    */
 , ATTACH4      varchar           (  256 )                                      /* 110 添付4    */
 , ATTACH5      varchar           (  256 )                                      /* 120 添付5    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員 */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者   */
);

==> openGion_dev_5.7.8.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE32S.sql <==
/****************************************************************************/
/* GE32 ( 送信履歴ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2014/06/13 18:57:51                                            */
/****************************************************************************/
CREATE TABLE GE32 (
   YKNO         INTEGER                         DEFAULT 0   NOT NULL            /*  10 要求NO   */
 , PARA_KEY     varchar           (    9 )                                      /*  20 ﾊﾟﾗﾒｰﾀｷｰ */
 , PTN_ID       varchar           (   20 )                                      /*  30 定型文ID */
 , SYSTEM_ID    varchar           (   10 )                  NOT NULL            /*  40 ｼｽﾃﾑID   */
 , FROM_ADDR    varchar           (  100 )                  NOT NULL            /*  50 送信元   */
 , TITLE        varchar           (  300 )                                      /*  60 ﾀｲﾄﾙ     */
 , CONTENTS     varchar           ( 4000 )                                      /*  70 内容     */
 , ATTACH1      varchar           (  256 )                                      /*  80 添付1    */
 , ATTACH2      varchar           (  256 )                                      /*  90 添付2    */
 , ATTACH3      varchar           (  256 )                                      /* 100 添付3    */
 , ATTACH4      varchar           (  256 )                                      /* 110 添付4    */
 , ATTACH5      varchar           (  256 )                                      /* 120 添付5    */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時 */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG   */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員 */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時 */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG   */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者   */
);
